@@ -6,6 +6,7 @@ import re
 #import time
 from datetime import datetime, timedelta
 #import jieba.posseg as psg
+import utils
 
 
 class Extractor:
@@ -184,10 +185,8 @@ class Extractor:
         index_list = []
         # 字典键值对用冒号分割，每个键值对之间用逗号分割，整个字典包括在花括号{}中
         # dict.get(key, default=None)返回指定键的值，如果值不在字典中返回default值
-        key_date = {'前天': -2, '前日': -2, '昨天': -1, '昨日': -1, '今天': 0, '今日': 0, '明天': 1, '明日': 1, '后天': 2, "现在": 0}
-        week_day = {'周一': 0, '周二': 1, '周三': 2, '周四': 3, '周五': 4, '周六': 5, '周天': 6, '周日': 6,
-                    "上周一":-7, "上周二":-6, "上周三":-5, "上周四":-4, "上周五":-3, "上周六":-2, "上周日":-1, "上周天":-1,
-                    "上上周一":-14, "上上周二":-13, "上上周三":-12, "上上周四":-11, "上上周五":-10, "上上周六":-9, "上上周日":-8, "上上周天":-8}
+        key_date = utils.key_date
+        week_day = utils.week_day
 
         # 检测英文写法日期8位数字
         date_dig = re.finditer(
@@ -242,97 +241,8 @@ class Extractor:
 
 
     def extract_number(self, cut_res):
-        direct_transform = {
-            "个百分点": ["%", 1],
-
-            "M": ["米", 1],
-            "毫米": ["米", 0.001],
-            "mm": ["米", 0.001],
-            "厘米": ["米", 0.01],
-            "cm":  ["米", 0.01],
-            "分米": ["米", 0.1],
-            "微米": ["米", 0.000001],
-            "千米": ["米", 1000],
-            "KM": ["米", 1000],
-            "公里": ["米", 1000],
-            "μm": ["米", 0.000001],
-            "英寸": ["米", 0.0254],
-            "inch": ["米", 0.0254],
-            "里": ["米", 500],
-            "尺": ["米", 0.3333333],
-
-            "毫升": ["L", 0.001],
-            "mL": ["L", 0.001],
-            "升": ["L", 1],
-            "L": ["L", 1],
-            "nL": ["L", 0.000000001],
-            "纳升": ["L", 0.000000001],
-            "立方米": ["L", 1000],
-            "立方分米": ["L", 1],
-            "立方厘米": ["L", 0.001],
-            "立方毫米": ["L", 0.000001],
-            "分升": ["L", 0.1],
-            "厘升": ["L", 0.01],
-
-            "平方千米": ["平方米", 1000000],
-            "公顷": ["平方米", 10000],
-            "平": ["平方米", 1],
-            "亩": ["平方米", 666.666666667],
-
-            "千克": ["千克", 1],
-            "吨": ["千克", 1000],
-            "g": ["千克", 0.001],
-            "克": ["千克", 0.001],
-            "公斤": ["千克", 1],
-            "斤": ["千克", 0.5],
-            "kg": ["千克", 1],
-            "t": ["千克", 1000],
-            "lb": ["千克", 0.4535924],
-
-            "人民币": ["元", 1],
-
-            "倍": ["倍", 1],
-            "辆": ["辆", 1],
-            "元": ["元", 1],
-
-            "米": ["米", 1],
-            "%": ["%", 1],
-            "平方米": ["平方米", 1],
-            "个": ["个", 1],
-            "股": ["股", 1],
-            "人次": ["人次", 1],
-            "颗": ["颗", 1],
-            "台": ["台", 1],
-            "瓶": ["瓶", 1],
-            "张": ["张", 1],
-            "篇": ["篇", 1],
-            "件": ["件", 1],
-
-            "伏特": ["V", 1],
-            "V": ["V", 1],
-            "伏": ["V", 1],
-
-            "赫兹": ["Hz", 1],
-            "Hz": ["Hz", 1],
-
-            "瓦": ["W", 1],
-            "瓦特": ["W", 1],
-            "千瓦": ["W", 1000],
-            "W": ["W", 1],
-            "kW": ["W", 1000],
-
-        }
-
-        general_transform = {
-            "万": 10000,
-            "亿": 100000000,
-            "万亿": 1000000000000,
-            "万万": 100000000,
-            "千": 1000,
-            "百": 100,
-            "千万": 10000000,
-            "万千": 10000000
-        }
+        direct_transform = utils.direct_transform
+        general_transform = utils.general_transform
 
         #分词、词性
         candidates = []
@@ -341,7 +251,7 @@ class Extractor:
         end_index = 0
         for i, (word, flag) in enumerate(cut_res):
             end_index += len(word)
-            if flag in ("m", "q", "mq"):
+            if flag in ("m", "q", "mq") or word.isdigit():
                 if not start_index:
                     start_index = end_index - len(word)
                 candidate += word
@@ -383,24 +293,17 @@ class Extractor:
         return final_res
 
 
-
-et = Extractor()
-import jieba.posseg as psg
-li = [
-    "今年产量10万吨",
-    "今年产量10.5L",
-    "pe 15倍的股票",
-    "涨了15%的股票",
-    "10万亿元",
-    "234立方厘米",
-    "目标是5个百分点"
-]
-
-for text in li:
-    cut_res = psg.lcut(text)
-    print(cut_res)
-    res = et.extract_number(cut_res)
-    print(res)
+    def extract_requirement(self, cut_res):
+        #word: [变量名/类型，从大到小排序？]
+        final_res = []
+        word_dict = utils.word_dict
+        word_list = [k for k, v in cut_res]
+        res = utils.max_backward_match(word_list, set(word_dict.keys()), max_k=3)
+        index_dict = utils.cut_text_index(word_list)
+        for elem in res:
+            tmp = word_dict[elem[0]]
+            final_res.append((elem[0], tmp[0], tmp[1], index_dict[elem[1]], index_dict[elem[2]]))
+        return final_res
 
 
 
@@ -411,6 +314,47 @@ for text in li:
 
 
 
+# et = Extractor()
+# import jieba.posseg as psg
+# li = [
+#     "今年产量10万吨",
+#     "今年产量10.5L",
+#     "pe 15倍的股票",
+#     "涨了15%的股票",
+#     "10万亿元",
+#     "234立方厘米",
+#     "目标是5个百分点"
+# ]
+#
+# for text in li:
+#     cut_res = psg.lcut(text)
+#     print(cut_res)
+#     res = et.extract_number(cut_res)
+#     print(res)
+
+
+
+# import time
+# et = Extractor()
+# import jieba.posseg as psg
+# li = [
+#     "最热的电视剧收藏最多最多点击erktkerktk3ktj34jr24j5   wqer423",
+#     "32r534t5345j34jtjfhwerhwhe问人家二姐跳舞机4今日就很入味人家4日34234234日发放开阔任何男人文化"
+# ]
+#
+# start = time.time()
+# for text in li:
+#     cut_res = psg.lcut(text)
+#     res = et.extract_requirement(cut_res)
+#     print(res)
+# #print((time.time() - start) / 2000)
+
+
+
+
+
+
+
 
 
 
